import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format,
} from 'd3';

const url = `https://gist.githubusercontent.com/nitanagdeote/bb42bb3798faf2a55be1e4a6e82ca493/raw/568207cf6758201f5c53ff73c3d8ed85e342ce2d/.csv`;

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisLabelText = 'Range(in miles)';
const titleText = 'Range of different EV Vehicles';
const margin = {
  top: 80,
  right: 80,
  bottom: 77,
  left: 200,
};

//////////////////////////////////////////////////

////////////////////////////////////////////////////

const render = (data) => {
  const xValue = (d) => d['Current Range(miles)'];
  const yValue = (d) => d['Vehicle'];

  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.5);

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  const xAxisTickFormat = (number) => format('')(number);

  const xAxis = axisBottom(xScale)
    .tickFormat(xAxisTickFormat)
    .tickSize(-innerHeight)

  g.append('g')
    .call(axisLeft(yScale))
    .selectAll('.domain, .tick line')
    .remove();

  const xAxisG = g
    .append('g')
    .call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`)
    ;

  xAxisG.select('.domain').remove();

  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', 65)
    .attr('x', innerWidth / 2)
    .attr('fill', 'black')
    .text(xAxisLabelText);

  g.selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('y', (d) => yScale(yValue(d)))
    .attr('width', (d) => xScale(xValue(d)))
    .attr('height', yScale.bandwidth())
    .append('title')
    .text((d) => `${d['Vehicle']}  :  ${d['Current Range(miles)']}`);

  g.append('text')
    .attr('class', 'title')
    .attr('y', -10)
    .text(titleText);
  
};

////////////////////////////////////////////////////
d3.csv(url).then((data) => {
  data.forEach((d) => {
    d['Current Range(miles)'] = +d['Current Range(miles)'];
    d['New Range(miles)'] = +d['New Range(miles)'];
  });
  render(data);
});
